%Diffraction pattern
% Loads datalogger files for lux vs voltage for grating of 100, 300 and 600 lines per mm
% Overlays Fraunhofer model upon data and generates graphs.
%
% LAST UPDATED by Andy French May 2017

function Diffraction_pattern

%Set (red) laser wavelength /nm
lamda = 650;

%Number of slits in beam (underestimate for clarity of presentation!)
N = 10;

%Set slit width /nm
w100 = 10*lamda;
w300 = 3.5*lamda;
w600 = 2*lamda;

%Determine slit spacing /nm
s100 = (1e-3/100)/1e-9;
s300 = (1e-3/300)/1e-9;
s600 = (1e-3/600)/1e-9;

%Set fontsize for graphs
fsize = 16;

%Set number of data points for model
Ndata = 1000;

%Set max and min angles /deg for graph
theta_min = -40;
theta_max = 40;

%

%Load 100 lines / mm data. t is time /sL is light level /lux. V is voltage
%/volts.
[t100,L100,V100] = textread('100 lines per mm.txt',...
    '%f%f%f',...
    'delimiter',' ',...
    'emptyvalue',NaN,...
    'headerlines',2);

%Load 300 lines / mm data. t is time /sL is light level /lux. V is voltage
%/volts.
[t300,L300,V300] = textread('300 lines per mm.txt',...
    '%f%f%f',...
    'delimiter',' ',...
    'emptyvalue',NaN,...
    'headerlines',2);

%Load 600 lines / mm data. t is time /sL is light level /lux. V is voltage
%/volts.
[t600,L600,V600] = textread('600 lines per mm.txt',...
    '%f%f%f',...
    'delimiter',' ',...
    'emptyvalue',NaN,...
    'headerlines',2);

%Convert voltages to angles /deg using calibration
theta100 = 133.52*V100 - 146.14;
theta300 = 133.52*V300 - 146.14;
theta600 = 133.52*V600 - 146.14;

%Normalize lux data
L100 = L100/max(L100);
L300 = L300/max(L300);
L600 = L600/max(L600);

%Work out model traces
theta = linspace(theta_min, theta_max, Ndata);
I100 = fraunhofer( lamda, theta, N, w100, s100 );
I300 = fraunhofer( lamda, theta, N, w300, s300 );
I600 = fraunhofer( lamda, theta, N, w600, s600 );

%Plot graphs
figure('name','diffraction pattern','color',[1 1 1])

%100 line s/mm
plot( theta, I100,'b',theta100,L100,'r+');
set(gca,'xlim',[theta_min,theta_max])
set(gca,'fontsize',fsize);
grid on;
xlabel('\theta /^o','fontsize',fsize)
ylabel('Normalized diffraction pattern power')
title('Diffraction pattern for 100 lines/mm grating','fontsize',fsize)
print(gcf,'DP 100 lines per mm.png','-dpng','-r300');
clf;

%300 line s/mm
plot( theta, I300,'b',theta300,L300,'r+');
set(gca,'xlim',[theta_min,theta_max])
set(gca,'fontsize',fsize);
grid on;
xlabel('\theta /^o','fontsize',fsize)
ylabel('Normalized diffraction pattern power')
title('Diffraction pattern for 300 lines/mm grating','fontsize',fsize)
print(gcf,'DP 300 lines per mm.png','-dpng','-r300');
clf;

%600 line s/mm
plot( theta, I600,'b',theta600,L600,'r+');
set(gca,'xlim',[theta_min,theta_max])
set(gca,'fontsize',fsize);
grid on;
xlabel('\theta /^o','fontsize',fsize)
ylabel('Normalized diffraction pattern power')
title('Diffraction pattern for 600 lines/mm grating','fontsize',fsize)
print(gcf,'DP 600 lines per mm.png','-dpng','-r300');
close(gcf)

%%

%Diffraction pattern model
% 
% I is diffraction pattern normalized power (max is unity)
% lamda is wavelength /nm
% N is number of slits
% w is slit width /nm
% s is slit spacing /nm
% theta is a vector of polar angles /deg

function I = fraunhofer( lamda, theta, N, w, s )

%Wavenumber /nm^-1
k = 2*pi/lamda;

%Convert angles to radians
theta = theta*pi/180;

%Determine intensity pattern amplitude variation with angle (i.e. range is
%the same)
I_s = ( sinN( 0.5*k*s*sin(theta),N) ).^2;
I_w = ( sinc( 0.5*k*w*sin(theta))  ).^2;
I = I_s.*I_w;

%%

function y = sinc(x)
y = ones(size(x));
k = x~=0;
y(k) = sin(x(k))./x((k));

%%

function y = sinN(x,N)
y = N*ones(size(x));
k = x~=0;
y(k) = sin(N*x(k))./(N*sin(x(k)));

%End of code






